<details><summary>What is the difference?</summary>
There are many scientists working in different groups to build and enhance computer models of the climate physics. These models operate at different scales in space and time.

In our case, we refer to i) global climate model projections with a spatial resolution of approx. 120 km of one pixel at the surface and to ii) regional climate model projections with a spatial resolution of approx. 11 km.

As the name suggests, global climate models (or GCMs) cover the whole globe. Their speciality is to simulate the overall physics of the atmosphere and land surface interactions. The regional climate models (or RCMs) build on top of GCMs and build physical and/or statistical relationships between GCM-outputs and locally observed weather. They seek to compensate the very coarse approximations of GCMs at the price of more data being extrapolated into the future.

For more detailed reading, please continue here:
[CarbonBrief - How do climate models work?](https://www.carbonbrief.org/qa-how-do-climate-models-work)
</details>